@@ -16,18 +16,19 @@
 import unittest
 
 
-NS = u'ns'
-FOO = u'foo'
-XXX = u'xxx'
-SPLAT = u'splat'
-SPLATV = u'splatv'
-A = u'a'
-AVALUE = u'avalue'
-B = u'b'
-BVALUE = u'bvalue'
+NS = 'ns'
+FOO = 'foo'
+XXX = 'xxx'
+SPLAT = 'splat'
+SPLATV = 'splatv'
+A = 'a'
+AVALUE = 'avalue'
+B = 'b'
+BVALUE = 'bvalue'
 
 # pylint:disable=protected-access
 
+
 class ZopeXMLConfigurationErrorTests(unittest.TestCase):
     maxDiff = None
 
@@ -46,7 +47,6 @@ class ZopeXMLConfigurationErrorTests(unittest.TestCase):
         )
 
 
-
 class ZopeSAXParseExceptionTests(unittest.TestCase):
     maxDiff = None
 
@@ -150,7 +150,7 @@ class ConfigurationHandlerTests(unittest.TestCase):
                                {ZCML_CONDITION: 'have nonesuch',
                                 (None, A): AVALUE,
                                 (None, B): BVALUE,
-                               })
+                                })
         self.assertEqual(handler.ignore_depth, 1)
 
     def test_startElementNS_w_ignore_depth_already_set(self):
@@ -163,7 +163,7 @@ class ConfigurationHandlerTests(unittest.TestCase):
                                {(XXX, SPLAT): SPLATV,
                                 (None, A): AVALUE,
                                 (None, B): BVALUE,
-                               })
+                                })
         self.assertEqual(handler.ignore_depth, 2)
 
     def _check_elementNS_context_raises(self, raises, catches,
@@ -174,8 +174,10 @@ class ConfigurationHandlerTests(unittest.TestCase):
             def end(self, *args):
                 raise raises("xxx")
             begin = end
-        class Info(object):
+
+        class Info:
             _line = _col = None
+
             def end(self, line, col):
                 self._line, self._col = line, col
         context = ErrorContext()
@@ -190,7 +192,8 @@ class ConfigurationHandlerTests(unittest.TestCase):
             meth(*meth_args)
         return exc.exception, info
 
-    def _check_startElementNS_context_begin_raises(self, raises, catches, testing=False):
+    def _check_startElementNS_context_begin_raises(
+            self, raises, catches, testing=False):
         return self._check_elementNS_context_raises(
             raises, catches, testing,
             meth='startElementNS',
@@ -199,13 +202,13 @@ class ConfigurationHandlerTests(unittest.TestCase):
                        {(XXX, SPLAT): SPLATV,
                         (None, A): AVALUE,
                         (None, B): BVALUE,
-                       })
+                        })
         )
 
     def test_startElementNS_context_begin_raises_wo_testing(self):
         from zope.configuration.xmlconfig import ZopeXMLConfigurationError
-        raised, _ = self._check_startElementNS_context_begin_raises(AttributeError,
-                                                                    ZopeXMLConfigurationError)
+        raised, _ = self._check_startElementNS_context_begin_raises(
+            AttributeError, ZopeXMLConfigurationError)
         info = raised.info
         self.assertEqual(info.file, 'tests//sample.zcml')
         self.assertEqual(info.line, 7)
@@ -222,7 +225,6 @@ class ConfigurationHandlerTests(unittest.TestCase):
         self._check_startElementNS_context_begin_raises(Bex,
                                                         Bex)
 
-
     def test_startElementNS_normal(self):
         # Integration test of startElementNS / endElementNS pair.
         context = FauxContext()
@@ -234,7 +236,7 @@ class ConfigurationHandlerTests(unittest.TestCase):
                                {(XXX, SPLAT): SPLATV,
                                 (None, A): AVALUE,
                                 (None, B): BVALUE,
-                               })
+                                })
         self.assertEqual(context.info.file, 'tests//sample.zcml')
         self.assertEqual(context.info.line, 1)
         self.assertEqual(context.info.column, 1)
@@ -252,14 +254,15 @@ class ConfigurationHandlerTests(unittest.TestCase):
         handler.endElementNS((NS, FOO), FOO)
         self.assertEqual(handler.ignore_depth, 0)
 
-    def _check_endElementNS_context_end_raises(self, raises, catches, testing=False):
+    def _check_endElementNS_context_end_raises(
+            self, raises, catches, testing=False):
         return self._check_elementNS_context_raises(raises, catches, testing)
 
     def test_endElementNS_context_end_raises_wo_testing(self):
         from zope.configuration.xmlconfig import ZopeXMLConfigurationError
 
-        raised, info = self._check_endElementNS_context_end_raises(AttributeError,
-                                                                   ZopeXMLConfigurationError)
+        raised, info = self._check_endElementNS_context_end_raises(
+            AttributeError, ZopeXMLConfigurationError)
 
         self.assertIs(raised.info, info)
         self.assertEqual(raised.info._line, 7)
@@ -363,8 +366,9 @@ class ConfigurationHandlerTests(unittest.TestCase):
                          "Invalid ZCML condition: 'nonesuch'")
 
     def test_endElementNS_normal(self):
-        class Info(object):
+        class Info:
             _line = _col = None
+
             def end(self, line, col):
                 self._line, self._col = line, col
         context = FauxContext()
@@ -387,9 +391,10 @@ class Test_processxmlfile(unittest.TestCase):
 
     def test_w_empty_xml(self):
         from io import StringIO
+
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.xmlconfig import ZopeSAXParseException
+        from zope.configuration.xmlconfig import registerCommonDirectives
 
         context = ConfigurationMachine()
         registerCommonDirectives(context)
@@ -401,8 +406,8 @@ class Test_processxmlfile(unittest.TestCase):
     def test_w_valid_xml_fp(self):
         # Integration test, really
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests.samplepackage import foo
+        from zope.configuration.xmlconfig import registerCommonDirectives
 
         context = ConfigurationMachine()
         registerCommonDirectives(context)
@@ -413,11 +418,13 @@ class Test_processxmlfile(unittest.TestCase):
         context.execute_actions()
         data = foo.data.pop()
         self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
-        self.assertEqual(clean_info_path(repr(data.info)),
-                         'File "tests/samplepackage/configure.zcml", line 12.2-12.29')
-        self.assertEqual(clean_info_path(str(data.info)),
-                         'File "tests/samplepackage/configure.zcml", line 12.2-12.29\n'
-                         + '    <test:foo x="blah" y="0" />')
+        self.assertEqual(
+            clean_info_path(repr(data.info)),
+            'File "tests/samplepackage/configure.zcml", line 12.2-12.29')
+        self.assertEqual(
+            clean_info_path(str(data.info)),
+            'File "tests/samplepackage/configure.zcml", line 12.2-12.29\n'
+            '    <test:foo x="blah" y="0" />')
         self.assertEqual(data.package, None)
         self.assertEqual(data.basepath, None)
 
@@ -430,6 +437,7 @@ class Test_openInOrPlain(unittest.TestCase):
 
     def _makeFilename(self, fn):
         import os
+
         from zope.configuration.tests.samplepackage import __file__
         return os.path.join(os.path.dirname(__file__), fn)
 
@@ -467,8 +475,8 @@ class Test_include(unittest.TestCase):
     def test_neither_file_nor_files_passed_already_seen(self):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests import samplepackage
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         context.package = samplepackage
@@ -476,16 +484,16 @@ class Test_include(unittest.TestCase):
         context._seen_files.add(fqn)
         logger = LoggerStub()
         with _Monkey(xmlconfig, logger=logger):
-            self._callFUT(context) #skips
+            self._callFUT(context)  # skips
         self.assertEqual(len(logger.debugs), 0)
         self.assertEqual(len(context.actions), 0)
 
     def test_neither_file_nor_files_passed(self):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         before_stack = context.stack[:]
@@ -505,11 +513,11 @@ class Test_include(unittest.TestCase):
         self.assertIn(fqn, context._seen_files)
 
     def test_w_file_passed(self):
+        from zope.configuration import tests
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration import tests
         from zope.configuration.tests import simple
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         before_stack = context.stack[:]
@@ -543,9 +551,9 @@ class Test_include(unittest.TestCase):
     def test_w_files_passed_and_package(self):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         before_stack = context.stack[:]
@@ -603,8 +611,8 @@ class Test_exclude(unittest.TestCase):
         self.assertIn(fqn, context._seen_files)
 
     def test_w_file_passed(self):
-        from zope.configuration.config import ConfigurationMachine
         from zope.configuration import tests
+        from zope.configuration.config import ConfigurationMachine
         context = ConfigurationMachine()
         context.package = tests
         fqn = _packageFile(tests, 'simple.zcml')
@@ -650,11 +658,11 @@ class Test_includeOverrides(unittest.TestCase):
         return includeOverrides(*args, **kw)
 
     def test_actions_have_parents_includepath(self):
+        from zope.configuration import tests
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration import tests
         from zope.configuration.tests import simple
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         fqp = _packageFile(tests, 'configure.zcml')
         registerCommonDirectives(context)
@@ -662,11 +670,12 @@ class Test_includeOverrides(unittest.TestCase):
         context.package = tests
         # dummy action, path from "previous" include
         context.includepath = (fqp,)
+
         def _callable():
             raise AssertionError("should not be called")
         context.actions.append({'discriminator': None,
                                 'callable': _callable,
-                               })
+                                })
         fqn = _packageFile(tests, 'simple.zcml')
         logger = LoggerStub()
         with _Monkey(xmlconfig, logger=logger):
@@ -741,9 +750,9 @@ class Test_file(unittest.TestCase):
     def test_wo_execute_w_context(self):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         context.package = samplepackage
         registerCommonDirectives(context)
@@ -764,6 +773,7 @@ class Test_file(unittest.TestCase):
 
     def test_w_execute(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
@@ -807,8 +817,8 @@ class Test_string(unittest.TestCase):
 
     def test_wo_execute_w_context(self):
         from zope.configuration.config import ConfigurationMachine
-        from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.tests.samplepackage import foo
+        from zope.configuration.xmlconfig import registerCommonDirectives
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         file_name = path("samplepackage", "configure.zcml")
@@ -843,14 +853,14 @@ class Test_string(unittest.TestCase):
 class XMLConfigTests(unittest.TestCase):
 
     def setUp(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
     def tearDown(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
@@ -863,6 +873,7 @@ class XMLConfigTests(unittest.TestCase):
 
     def test_ctor_w_global_context_missing(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests.samplepackage import foo
         here = os.path.dirname(__file__)
@@ -873,7 +884,7 @@ class XMLConfigTests(unittest.TestCase):
             xc = self._makeOne(path)
         self.assertEqual(len(logger.debugs), 1)
         self.assertEqual(logger.debugs[0], ('include %s', (path,), {}))
-        self.assertEqual(len(foo.data), 0) # no execut_actions
+        self.assertEqual(len(foo.data), 0)  # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
@@ -890,7 +901,7 @@ class XMLConfigTests(unittest.TestCase):
             xc = self._makeOne(fqn)
         self.assertEqual(len(logger.debugs), 1)
         self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
-        self.assertEqual(len(foo.data), 0) # no execut_actions
+        self.assertEqual(len(foo.data), 0)  # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
@@ -899,15 +910,15 @@ class XMLConfigTests(unittest.TestCase):
 
     def test_ctor_w_module(self):
         from zope.configuration import xmlconfig
-        from zope.configuration.tests.samplepackage import foo
         from zope.configuration.tests import samplepackage
+        from zope.configuration.tests.samplepackage import foo
         fqn = _packageFile(samplepackage, 'configure.zcml')
         logger = LoggerStub()
         with _Monkey(xmlconfig, logger=logger):
             xc = self._makeOne("configure.zcml", samplepackage)
         self.assertEqual(len(logger.debugs), 1)
         self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
-        self.assertEqual(len(foo.data), 0) # no execut_actions
+        self.assertEqual(len(foo.data), 0)  # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
@@ -916,6 +927,7 @@ class XMLConfigTests(unittest.TestCase):
 
     def test___call__(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
@@ -926,7 +938,7 @@ class XMLConfigTests(unittest.TestCase):
         self.assertEqual(len(logger.debugs), 1)
         self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(foo.data), 0)
-        xc() # call to process the actions
+        xc()  # call to process the actions
         self.assertEqual(len(foo.data), 1)
         data = foo.data.pop(0)
         self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
@@ -939,18 +951,17 @@ class XMLConfigTests(unittest.TestCase):
         self.assertEqual(data.info.ecolumn, 29)
 
 
-
 class Test_xmlconfig(unittest.TestCase):
 
     def setUp(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
     def tearDown(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
@@ -960,9 +971,11 @@ class Test_xmlconfig(unittest.TestCase):
 
     def test_wo_testing_passed(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+
         def _assertTestingFalse(func):
             def _wrapper(*args, **kw):
                 assert not kw['testing']
@@ -988,9 +1001,11 @@ class Test_xmlconfig(unittest.TestCase):
 
     def test_w_testing_passed(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+
         def _assertTestingTrue(func):
             def _wrapper(*args, **kw):
                 assert kw['testing']
@@ -1018,14 +1033,14 @@ class Test_xmlconfig(unittest.TestCase):
 class Test_testxmlconfig(unittest.TestCase):
 
     def setUp(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
     def tearDown(self):
-        from zope.configuration.xmlconfig import _clearContext
         from zope.configuration.tests.samplepackage.foo import data
+        from zope.configuration.xmlconfig import _clearContext
         _clearContext()
         del data[:]
 
@@ -1035,9 +1050,11 @@ class Test_testxmlconfig(unittest.TestCase):
 
     def test_w_testing_passed(self):
         import os
+
         from zope.configuration import xmlconfig
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
+
         def _assertTestingTrue(func):
             def _wrapper(*args, **kw):
                 assert kw['testing']
@@ -1062,31 +1079,38 @@ class Test_testxmlconfig(unittest.TestCase):
         self.assertEqual(data.info.ecolumn, 29)
 
 
-
-class FauxLocator(object):
+class FauxLocator:
     def __init__(self, file, line, column):
         self.file, self.line, self.column = file, line, column
+
     def getSystemId(self):
         return self.file
+
     def getLineNumber(self):
         return self.line
+
     def getColumnNumber(self):
         return self.column
 
 
-class FauxContext(object):
+class FauxContext:
     includepath = ()
     _features = ()
     _end_called = False
+
     def setInfo(self, info):
         self.info = info
+
     def getInfo(self):
         return self.info
+
     def begin(self, name, data, info):
         self.begin_args = name, data
         self.info = info
+
     def end(self):
         self._end_called = 1
+
     def hasFeature(self, feature):
         return feature in self._features
 
@@ -1095,6 +1119,7 @@ def path(*p):
     import os
     return os.path.join(os.path.dirname(__file__), *p)
 
+
 def clean_info_path(s):
     import os
     part1 = s[:6]
@@ -1102,7 +1127,8 @@ def clean_info_path(s):
     part2 = part2[part2.rfind("tests"):]
     part2 = part2.replace(os.sep, '/')
     part3 = s[s.find('"', 6):].rstrip()
-    return part1+part2+part3
+    return part1 + part2 + part3
+
 
 def clean_path(s):
     import os
@@ -1110,6 +1136,7 @@ def clean_path(s):
     s = s.replace(os.sep, '/')
     return s
 
+
 def clean_actions(actions):
     return [
         {
@@ -1120,15 +1147,16 @@ def clean_actions(actions):
         for action in actions
     ]
 
+
 def clean_text_w_paths(error):
     r = []
     for line in str(error).split("\n"):
         line = line.rstrip()
         if not line:
             continue
-        l = line.find('File "')
-        if l >= 0:
-            line = line[:l] + clean_info_path(line[l:])
+        l_ = line.find('File "')
+        if l_ >= 0:
+            line = line[:l_] + clean_info_path(line[l_:])
         r.append(line)
     return '\n'.join(r)
 
@@ -1137,7 +1165,8 @@ def _packageFile(package, filename):
     import os
     return os.path.join(os.path.dirname(package.__file__), filename)
 
-class _Monkey(object):
+
+class _Monkey:
 
     def __init__(self, module, **replacements):
         self.module = module
@@ -1155,11 +1184,11 @@ class _Monkey(object):
         for k in self.replacements:
             if k in self.orig:
                 setattr(self.module, k, self.orig[k])
-            else: # pragma: no cover
+            else:  # pragma: no cover
                 delattr(self.module, k)
 
 
-class LoggerStub(object):
+class LoggerStub:
 
     debugs = errors = warnings = infos = ()
 
